==> tomee-project-8.0.10-source-release.zip: tomee-project-8.0.10/maven/tomee-webapp-archetype/src/main/resources/archetype-resources/src/main/java/presentation/BookBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package ${package}.presentation;

import ${package}.application.BookService;
import ${package}.entities.Book;

import javax.inject.Inject;
import javax.inject.Named;
import java.util.List;

@Named
public class BookBean {

    @Inject
    private BookService bookService;
    private List<Book> booksAvailable;
    private String bookTitle;

    public String getBookTitle() {
        return bookTitle;
    }

    public void setBookTitle(String bookTitle) {
        this.bookTitle = bookTitle;
    }

    public List<Book> getBooksAvailable() {
        return booksAvailable;
    }

    public void setBooksAvailable(List<Book> booksAvailable) {
        this.booksAvailable = booksAvailable;
    }

    public String fetchBooks()
    {
        booksAvailable=bookService.getAllBooks();
        return "success";
    }

    public String add()
    {
        Book book = new Book();
        book.setBookTitle(bookTitle);
        bookService.addBook(book);
        return "success";
    }
}

==> tomee-project-10.1.4-source-release.zip: tomee-project-10.1.4/maven/tomee-webapp-archetype/src/main/resources/archetype-resources/src/main/java/presentation/BookBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package ${package}.presentation;

import ${package}.application.BookService;
import ${package}.entities.Book;

import jakarta.inject.Inject;
import jakarta.inject.Named;
import java.util.List;

@Named
public class BookBean {

    @Inject
    private BookService bookService;
    private List<Book> booksAvailable;
    private String bookTitle;

    public String getBookTitle() {
        return bookTitle;
    }

    public void setBookTitle(String bookTitle) {
        this.bookTitle = bookTitle;
    }

    public List<Book> getBooksAvailable() {
        return booksAvailable;
    }

    public void setBooksAvailable(List<Book> booksAvailable) {
        this.booksAvailable = booksAvailable;
    }

    public String fetchBooks()
    {
        booksAvailable=bookService.getAllBooks();
        return "success";
    }

    public String add()
    {
        Book book = new Book();
        book.setBookTitle(bookTitle);
        bookService.addBook(book);
        return "success";
    }
}
